@@ -29,7 +29,6 @@
 #include <QLabel>
 #include <QLayout>
 #include <QLineEdit>
-#include <QPixmap>
 #include <QPushButton>
 #include <QSlider>
 #include <QToolButton>
@@ -44,6 +43,7 @@
 
 #include <libs/main/KoDocument.h>
 #include <KoColorProfile.h>
+#include <KoConfigAuthorPage.h>
 
 #include <kmessagebox.h>
 #include <kcolorbutton.h>
@@ -317,12 +317,18 @@ void TabletSettingsTab::setDefault()
 TabletSettingsTab::TabletSettingsTab(QWidget* parent, const char* name): QWidget(parent)
 {
     setObjectName(name);
+
+    QGridLayout * l = new QGridLayout(this);
+    l->setSpacing(KDialog::spacingHint());
+    l->setMargin(0);
     m_page = new WdgTabletSettings(this);
+    l->addWidget(m_page, 0, 0);
 
     KisConfig cfg;
     KisCubicCurve curve;
     curve.fromString( cfg.pressureTabletCurve() );
 
+    m_page->pressureCurve->setMaximumSize(QSize(QWIDGETSIZE_MAX, QWIDGETSIZE_MAX));
     m_page->pressureCurve->setCurve(curve);
 }
 
@@ -357,10 +363,13 @@ DisplaySettingsTab::DisplaySettingsTab(QWidget *parent, const char *name)
         cbUseOpenGL->setEnabled(false);
         cbUseOpenGLShaders->setEnabled(false);
         cbUseOpenGLToolOutlineWorkaround->setEnabled(false);
+        cbUseOpenGLTrilinearFiltering->setEnabled(false);
     } else {
         cbUseOpenGL->setChecked(cfg.useOpenGL());
         cbUseOpenGLToolOutlineWorkaround->setEnabled(cfg.useOpenGL());
         cbUseOpenGLToolOutlineWorkaround->setChecked(cfg.useOpenGLToolOutlineWorkaround());
+        cbUseOpenGLTrilinearFiltering->setEnabled(cfg.useOpenGL());
+        cbUseOpenGLTrilinearFiltering->setChecked(cfg.useOpenGLTrilinearFiltering());
 #ifdef HAVE_GLEW
         if (KisOpenGL::hasShadingLanguage()) {
             cbUseOpenGLShaders->setChecked(cfg.useOpenGLShaders());
@@ -402,6 +411,8 @@ void DisplaySettingsTab::setDefault()
     cbUseOpenGLShaders->setEnabled(false);
     cbUseOpenGLToolOutlineWorkaround->setChecked(false);
     cbUseOpenGLToolOutlineWorkaround->setEnabled(false);
+    cbUseOpenGLTrilinearFiltering->setEnabled(false);
+    cbUseOpenGLTrilinearFiltering->setChecked(true);
     chkMoving->setChecked(true);
     intCheckSize->setValue(32);
     colorChecks->setColor(QColor(220, 220, 220));
@@ -417,6 +428,7 @@ void DisplaySettingsTab::slotUseOpenGLToggled(bool isChecked)
     }
 #endif
     cbUseOpenGLToolOutlineWorkaround->setEnabled(isChecked);
+    cbUseOpenGLTrilinearFiltering->setEnabled(isChecked);
 #else
     Q_UNUSED(isChecked);
 #endif
@@ -602,10 +614,10 @@ KisDlgPreferences::KisDlgPreferences(QWidget* parent, const char* name)
     vbox = new KVBox();
     page = new KPageWidgetItem(vbox, i18n("Tablet settings"));
     page->setHeader(i18n("Tablet"));
-    page->setIcon(KIcon("preferences-system-performance"));
+    page->setIcon(KIcon("input-tablet"));
     addPage(page);
     m_tabletSettings = new TabletSettingsTab(vbox);
-    m_tabletSettings->m_page->pressureCurve->setMaximumSize(QSize(1000, 1000));
+
 
     // full-screen mode
     vbox = new KVBox();
@@ -616,6 +628,14 @@ KisDlgPreferences::KisDlgPreferences(QWidget* parent, const char* name)
     m_fullscreenSettings = new FullscreenSettingsTab(vbox);
 
 
+    // author settings
+    vbox = new KVBox();
+    m_authorSettings = new KoConfigAuthorPage();
+    page = addPage(m_authorSettings, i18nc("@title:tab Author page", "Author"));
+    page->setHeader(i18n("Author"));
+    page->setIcon(KIcon("user-identity"));
+
+
     KisPreferenceSetRegistry *preferenceSetRegistry = KisPreferenceSetRegistry::instance();
     foreach (KisAbstractPreferenceSetFactory *preferenceSetFactory, preferenceSetRegistry->values()) {
         KisPreferenceSet* preferenceSet = preferenceSetFactory->createPreferenceSet();
@@ -712,6 +732,7 @@ bool KisDlgPreferences::editPreferences()
         cfg.setUseOpenGL(dialog->m_displaySettings->cbUseOpenGL->isChecked());
         cfg.setUseOpenGLShaders(dialog->m_displaySettings->cbUseOpenGLShaders->isChecked());
         cfg.setUseOpenGLToolOutlineWorkaround(dialog->m_displaySettings->cbUseOpenGLToolOutlineWorkaround->isChecked());
+        cfg.setUseOpenGLTrilinearFiltering(dialog->m_displaySettings->cbUseOpenGLTrilinearFiltering->isChecked());
 #else
         cfg.setUseOpenGLToolOutlineWorkaround(false);
 #endif
@@ -743,6 +764,7 @@ bool KisDlgPreferences::editPreferences()
         cfg.setHideTitlebarFullscreen(dialog->m_fullscreenSettings->chkTitlebar->checkState());
         cfg.setHideToolbarFullscreen(dialog->m_fullscreenSettings->chkToolbar->checkState());
 
+        dialog->m_authorSettings->apply();
     }
     delete dialog;
     return baccept;
