@@ -85,6 +85,7 @@
 #include "kis_progress_widget.h"
 #include "kis_node_commands_adapter.h"
 #include "kis_node_manager.h"
+#include "kis_mirror_visitor.h"
 
 
 KisLayerManager::KisLayerManager(KisView2 * view, KisDoc2 * doc)
@@ -591,82 +592,6 @@ void KisLayerManager::layerBack()
     layer->parent()->setDirty();
 }
 
-void KisLayerManager::mirrorLayerX()
-{
-    KisLayerSP layer = activeLayer();
-    m_view->image()->undoAdapter()->beginMacro(i18n("Mirror Layer X"));
-
-    if (layer->inherits("KisShapeLayer")) {
-
-        KisTransformVisitor visitor(m_view->image(), -1.0, 1.0, 0.0, 0.0, 0.0, m_view->image()->width(), 0, 0, 0);
-        layer->accept(visitor);
-    } else {
-        KisPaintDeviceSP dev = activeDevice();
-        if (!dev) return;
-
-        KisTransaction transaction(i18n("Mirror Layer X"), dev);
-
-        QRect dirty = KisTransformWorker::mirrorX(dev, m_view->selection());
-        m_activeLayer->setDirty(dirty);
-
-        transaction.commit(m_view->image()->undoAdapter());
-    }
-    // Now for the masks
-    KoProperties properties;
-    foreach(KisNodeSP mask, layer->childNodes(QStringList("KisMask"), properties)) {
-        KisPaintDeviceSP dev = qobject_cast<KisMask*>(mask.data())->selection()->getOrCreatePixelSelection();
-        if (!dev) continue;
-        KisTransaction transaction(i18n("Mirror Mask X"), dev);
-        QRect dirty = KisTransformWorker::mirrorX(dev, m_view->selection());
-        transaction.commit(m_view->image()->undoAdapter());
-        mask->setDirty(dirty);
-    }
-
-    m_view->image()->undoAdapter()->endMacro();
-    m_doc->setModified(true);
-    layersUpdated();
-    m_view->canvas()->update();
-}
-
-void KisLayerManager::mirrorLayerY()
-{
-    KisLayerSP layer = activeLayer();
-
-    m_view->image()->undoAdapter()->beginMacro(i18n("Mirror Layer Y"));
-
-    if (layer->inherits("KisShapeLayer")) {
-        KisTransformVisitor visitor(m_view->image(), 1.0, -1.0, 0.0, 0.0, 0.0, 0, m_view->image()->height(), 0, 0);
-        layer->accept(visitor);
-
-    } else {
-        KisPaintDeviceSP dev = activeDevice();
-        if (!dev) return;
-
-        KisTransaction transaction(i18n("Mirror Layer Y"), dev);
-
-        QRect dirty = KisTransformWorker::mirrorY(dev, m_view->selection());
-        m_activeLayer->setDirty(dirty);
-
-        transaction.commit(m_view->image()->undoAdapter());
-    }
-    // Now for the masks
-    KoProperties properties;
-    foreach(KisNodeSP mask, layer->childNodes(QStringList("KisMask"), properties)) {
-        KisPaintDeviceSP dev = qobject_cast<KisMask*>(mask.data())->selection()->getOrCreatePixelSelection();
-        if (!dev) continue;
-        KisTransaction transaction(i18n("Mirror Mask Y"), dev);
-        QRect dirty = KisTransformWorker::mirrorY(dev, m_view->selection());
-        transaction.commit(m_view->image()->undoAdapter());
-        mask->setDirty(dirty);
-    }
-
-    m_view->image()->undoAdapter()->endMacro();
-
-    m_doc->setModified(true);
-    layersUpdated();
-    m_view->canvas()->update();
-}
-
 void KisLayerManager::scaleLayer(double sx, double sy, KisFilterStrategy *filterStrategy)
 {
     if (!m_view->image()) return;
